@@ -20,7 +20,7 @@ import os.path
 import subprocess
 import logging
 
-from gi.repository import Gtk, Gdk, GLib, Gio
+from gi.repository import Gtk, Gdk, GLib, Gio, GObject
 
 from gtweak.tweakmodel import Tweak
 from gtweak.widgets import ListBoxTweakGroup, UI_BOX_SPACING
@@ -32,7 +32,8 @@ def _list_header_func(row, before, user_data):
 
 class _AppChooser(Gtk.Dialog):
     def __init__(self, main_window, running_exes, startup_apps):
-        Gtk.Dialog.__init__(self, title=_("Applications"))
+        uhb = Gtk.Settings.get_default().props.gtk_dialogs_use_header
+        Gtk.Dialog.__init__(self, title=_("Applications"), use_header_bar=uhb)
 
         self._running = {}
         self._all = {}
@@ -45,6 +46,8 @@ class _AppChooser(Gtk.Dialog):
         self.searchbar = Gtk.SearchBar()
         self.searchbar.add(self.entry)
         self.searchbar.props.hexpand = True
+        # Translators: This is the accelerator for opening the AppChooser search-bar
+        self._search_key, self._search_mods = Gtk.accelerator_parse(_("<primary>f"))
 
         lb = Gtk.ListBox()
         lb.props.margin = 5
@@ -73,10 +76,21 @@ class _AppChooser(Gtk.Dialog):
         sw.props.hscrollbar_policy = Gtk.PolicyType.NEVER
         sw.add(lb)
 
-        self.add_button(_("_Close"), Gtk.ResponseType.CLOSE)
-        self.add_button(_("Add Application"), Gtk.ResponseType.OK)
+        self.add_button(_("_Close"), Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Add"), Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
 
+        if self.props.use_header_bar:
+            searchbtn = Gtk.ToggleButton()
+            searchbtn.props.valign = Gtk.Align.CENTER
+            image = Gtk.Image(icon_name = "edit-find-symbolic", icon_size = Gtk.IconSize.MENU)
+            searchbtn.add(image)
+            context = searchbtn.get_style_context()
+            context.add_class("image-button")
+            context.remove_class("text-button")
+            self.get_header_bar().pack_end(searchbtn)
+            self._binding = searchbtn.bind_property("active", self.searchbar, "search-mode-enabled", GObject.BindingFlags.BIDIRECTIONAL)
+
         self.get_content_area().pack_start(self.searchbar, False, False, 0)
         self.get_content_area().pack_start(sw, True, True, 0)
         self.set_modal(True)
@@ -156,6 +170,10 @@ class _AppChooser(Gtk.Dialog):
             self.set_response_sensitive(Gtk.ResponseType.OK, False)
 
     def _on_key_press(self, widget, event):
+      mods = event.state & Gtk.accelerator_get_default_mod_mask()
+      if event.keyval == self._search_key and mods == self._search_mods:
+          self.searchbar.set_search_mode(not self.searchbar.get_search_mode())
+          return True
       keyname = Gdk.keyval_name(event.keyval)
       if keyname == 'Escape':
           if self.searchbar.get_search_mode():
